@@ -146,7 +146,7 @@ class App:
 
     def get_cookie(self, key):
         cookies = {}
-        for key, value in dict(self.cur_req.cookies):
+        for key, value in dict(self.cur_req.cookies).items():
             if key not in ["hblid", "olfsk"]:
                 cookies[key] = value
         return cookies
